@@ -24,24 +24,20 @@
 #include <kuser.h>
 
 #if HAVE_X11
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
 #include <X11/Xatom.h>
 #include <X11/Xlib.h>
 #include <fixx11h.h>
 #include <kwindowsystem.h>
 #include <netwm.h>
+#include <private/qtx11extras_p.h>
 
 struct WindowInfo {
     WindowInfo(WId _wid, qlonglong _pid)
-         : wid(_wid)
+        : wid(_wid)
+        , pid(_pid)
     {
-        pid = 0;
-        pid = _pid;
     }
+
     qlonglong pid;
     QPixmap icon;
     WId wid;
@@ -199,9 +195,9 @@ public:
     static const int MAX_HIST_ENTRIES = 100;
     static const int MIN_HIST_AGE = 200; ///< If the latest history entry is at least this ms old, a new one gets added
     /** Storage for the history entries. We need one per percentage column. */
-    QHash<KSysGuard::Process *, QVector<ProcessModel::PercentageHistoryEntry>> mMapProcessCPUHistory;
+    QHash<KSysGuard::Process *, QList<ProcessModel::PercentageHistoryEntry>> mMapProcessCPUHistory;
 
-    QVector<KSysGuard::ProcessAttribute *> mExtraAttributes;
+    QList<KSysGuard::ProcessAttribute *> mExtraAttributes;
 
 #if HAVE_XRES
     bool mHaveXRes; ///< True if the XRes extension is available at run time
